summaryrefslogtreecommitdiffstats
path: root/chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js')
-rw-r--r--chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js8
1 files changed, 6 insertions, 2 deletions
diff --git a/chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js b/chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js
index 03c6caa..bcb1219 100644
--- a/chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js
+++ b/chrome/renderer/resources/extensions/sync_file_system_custom_bindings.js
@@ -2,13 +2,15 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-// Custom bindings for the syncFileSystem API.
+// Custom binding for the syncFileSystem API.
+
+var binding = require('binding').Binding.create('syncFileSystem');
var chromeHidden = requireNative('chrome_hidden').GetChromeHidden();
var fileSystemNatives = requireNative('file_system_natives');
var syncFileSystemNatives = requireNative('sync_file_system');
-chromeHidden.registerCustomHook('syncFileSystem', function(bindingsAPI) {
+binding.registerCustomHook(function(bindingsAPI) {
var apiFunctions = bindingsAPI.apiFunctions;
// Functions which take in an [instanceOf=FileEntry].
@@ -67,3 +69,5 @@ chromeHidden.Event.registerArgumentMassager(
}
dispatch([fileInfo]);
});
+
+exports.binding = binding.generate();